TelemetryData class

Strongly typed telemetry snapshot container.

This class ensures type safety when retrieving values.

Constructors

TelemetryData(Map<DetailedPID, dynamic> _values, {DateTime? timestamp})
Creates a telemetry data snapshot.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
Timestamp of this telemetry snapshot.
final

Methods

get<T>(DetailedPID<T> detailedPID) → T?
Retrieves a strongly typed value.
hasData(DetailedPID detailedPID) bool
Returns true if data exists for a PID.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited