SaeJ1979 class
SAE = Society of Automotive Engineers J1979 = The specific standard for OBD-II diagnostics.
SAE J1979 diagnostic standard implementation.
This class handles the formatting of commands and the parsing of responses according to the SAE J1979 protocol.
Constructors
- SaeJ1979(AdapterOBD2 adapter)
Properties
- adapter → AdapterOBD2
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
no setter
-
initializationCommands
→ List<
String> -
no setter
- name → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- telemetry ↔ Telemetry
-
latefinal
Methods
-
buildDetailedPIDRequest(
DetailedPID detailedPID) → String -
extractDataBytes(
{required String response, required DetailedPID detailedPID}) → List< String> - Extracts raw data bytes from a raw ELM327 response string.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited